<template>
    <div class="app-container">
        <div class="filter-container">
            <el-button class="filter-item" style="margin-left: 10px;" type="primary"  @click="openAnnualInventoryForm('新增','')">添加</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="annualInventoryListData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="年度" prop="year" align="center">
                </el-table-column>
                <el-table-column label="类别" prop="type" align="center">
                </el-table-column>
                <el-table-column label="数量" prop="amount" align="center">
                </el-table-column>
                <el-table-column label="添加时间" prop="createtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="openAnnualInventoryForm('查看',scope.row)">选择</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <annualInventoryForm ref="annualInventoryForm" @getinfo="getAnnualInventoryDataListData"></annualInventoryForm>
    </div>
</template>

<script>
import annualInventoryForm from "./components/annualInventoryForm";
import { computePageCount } from '@/utils'
import {  getAnnualInventoryList } from '@/api/AnnualInventory'
export default {
    name: "publicSecurityDepartment",
    props:["enterpriseId"],
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            annualInventoryListData:[],
        }
    },
    components:{
        annualInventoryForm
    },
    created(){
        this.getAnnualInventoryDataListData()
    },
    methods:{
        async getAnnualInventoryDataListData(){
            const params = {}
            params['pageIndex'] = this.currentPage
            params['pageSize'] = this.pageSize
            this.listLoading = true
            let res = await getAnnualInventoryList(params,this.enterpriseId)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.annualInventoryListData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        openAnnualInventoryForm(title,value){
            this.$refs.annualInventoryForm.showAnnualInventoryForm(title,value,this.enterpriseId)
        },
        queryHandle(){
            this.getAnnualInventoryDataListData()
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getAnnualInventoryDataListData()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getAnnualInventoryDataListData()
        },
    }
}
</script>

<style scoped>

</style>
